/**
   chat: a TCP/IP chatting program
   Copyright (C) 2006  Idan Nof

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Idan Nof can be reached via -

   email: idannof (at) hotmail (dot) com
   web  : http://www.geocities.com/idannof
   paper: 3 Brande st.,
		  Petach-Tikva, 49600,
		  Israel
*/
package Client;

import javax.swing.JTextArea;

import Util.SynchedFifo;

/**
 * A thread responsible for sitting on the server-echo FIFO and writing them on the GUI
 */
public class GuiEchoListener extends Thread {
	/**
	 * a reference for the TextArea to write in
	 */
	private JTextArea echoArea;

	/**
	 * A constructor that saves a reference for a window to write in
	 * @param echoArea The TextArea to write in
	 */
	GuiEchoListener(JTextArea echoArea) {
		this.echoArea = echoArea;
	}

	/**
	 * A front-end for this thread.
	 * Infinitely waits for messages on StaticFifos.ServerEcho() and writes them
	 * to the relevant GUI's text area
	 */
	public void run() {
		SynchedFifo serverEcho = StaticFifos.getServerEcho();
		while (true) {
			synchronized (serverEcho) {
				while (serverEcho.isEmpty()) {
					try {
						serverEcho.wait();
						echoArea.append(serverEcho.get() + "\n");
					} catch (InterruptedException e) {
						System.out.println(
							"Stop request detected while blocking in GuiEchoListener.");
						serverEcho.reset();
						return;
					} // catch block
				} // inner while
			} // synchronized
		} // outer while
	}

}