/**
   chat: a TCP/IP chatting program
   Copyright (C) 2006  Idan Nof

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Idan Nof can be reached via -

   email: idannof (at) hotmail (dot) com
   web  : http://www.geocities.com/idannof
   paper: 3 Brande st.,
		  Petach-Tikva, 49600,
		  Israel
*/
package Client;

import java.io.BufferedWriter;

import Util.SynchedFifo;
import Util.Util;

/**
 * A thread that sits and wait for messages and sends them over the network 
 */
public class UserSend extends Thread {
	/**
	 * The socket output to send messages to
	 */
	private final BufferedWriter out;

	UserSend(BufferedWriter out) {
		this.out = out;
	}

	/**
	 * Infinitely send messages from StaticFifos.getUserInput over the network
	 */
	public void run() {
		SynchedFifo userInput = StaticFifos.getUserInput();
		while (true) {
			synchronized (userInput) {
				while (userInput.isEmpty()) {
					try {
						userInput.wait();
					} catch (InterruptedException e) {
						System.out.println(
							"Stop request detected while blocking in UserSend.");
						userInput.reset();
						return;
					}

					Util.sendLine(userInput.get(), out);
				} // inner while
			} // synchronized
		} // outer while
	}

}
