/**
   chat: a TCP/IP chatting program
   Copyright (C) 2006  Idan Nof

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Idan Nof can be reached via -

   email: idannof (at) hotmail (dot) com
   web  : http://www.geocities.com/idannof
   paper: 3 Brande st.,
		  Petach-Tikva, 49600,
		  Israel
*/
package Util;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.StringTokenizer;

import Server.Session;

/**
 * User I/O static utility functions
 */
public final class UserIO {
	/** 
	 * The space separator
	 */
	private static final String TOK_SPACE = " ";

	/**
	 * The user prompt string
	 */
	private static final String PROMPT_STR = "> ";

	/**
	 * The open command.
	 * Note: case sensitive!
	 */
	private static final String OPEN_STR = "open";

	/**
	 * Read a line from the user console (stdin)
	 */
	public static final String readLine() {
		BufferedReader stdin =
			new BufferedReader(new InputStreamReader(System.in));

		System.out.print("\n" + PROMPT_STR);

		String line;
		while (true) {
			try {
				line = stdin.readLine();
				return line;
			} catch (IOException e) {
				System.out.println("IOException at readLine()");
			}
		} // while
	} // readLine()

	/**
	 * Read an open command from the user.
	 * The syntax of the command: 'open SessionName'
	 */
	public static final Session parseOpenCommand(String line) {
		String serviceName = null;
		String sessionName = null;

		StringTokenizer stoke = null;
		String nextToken = null;

		/**
		 * A predicate that indicates whether we are expecting more input characters
		 */
		boolean expectMore = false;
		
		int i = 0;
		stoke = new StringTokenizer(line, TOK_SPACE, false);
		
		while (stoke.hasMoreElements()) {
			nextToken = stoke.nextToken();
			switch (i) {
				case 0 :
					if (!nextToken.equals(OPEN_STR)) {
						return null;
					}
					expectMore = true;
					break;
				case 1 :
					sessionName = new String(nextToken);
					expectMore = false;
					break;
				default :
					System.err.println("Error: excess number of arguments ");
					return null;
			} // switch

			i++;
		} // while

		if (expectMore) {
			System.err.println("Error: expected more arguments");
			return null;
		} // if

		return new Session(serviceName, sessionName);
	} // getSelection()

} // UserIO class
